@@ -248,9 +248,9 @@ DecodeIPV6ExtHdrs(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p, uint8_t *pkt
                         //    addr_buf,sizeof(addr_buf));
                         //printf("home addr %s\n", addr_buf);
                     }
-                    uint16_t len = (*(ptr + 1) + 2);
-                    ptr += len; /* +2 for opt type and opt len fields */
-                    offset += len;
+                    uint16_t optlen = (*(ptr + 1) + 2);
+                    ptr += optlen; /* +2 for opt type and opt len fields */
+                    offset += optlen;
                 }
 
                 nh = *pkt;
@@ -411,8 +411,6 @@ void DecodeIPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p, uint8_t *pkt,
 
     SCPerfCounterIncr(dtv->counter_ipv6, tv->sc_perf_pca);
 
-    IPV6_CACHE_INIT(p);
-
     /* do the actual decoding */
     ret = DecodeIPV6Packet (tv, dtv, p, pkt, len);
     if (ret < 0) {
