@@ -582,6 +582,9 @@ Defrag4Reassemble(ThreadVars *tv, DefragContext *dc, DefragTracker *tracker,
         }
     }
 
+    if (rp == NULL)
+        goto done;
+
     rp->ip4h = (IPV4Hdr *)(rp->pkt + ip_hdr_offset);
     int old = rp->ip4h->ip_len + rp->ip4h->ip_off;
     rp->ip4h->ip_len = htons(fragmentable_len + hlen);
@@ -589,12 +592,11 @@ Defrag4Reassemble(ThreadVars *tv, DefragContext *dc, DefragTracker *tracker,
     rp->ip4h->ip_csum = FixChecksum(rp->ip4h->ip_csum,
         old, rp->ip4h->ip_len + rp->ip4h->ip_off);
     rp->pktlen = ip_hdr_offset + hlen + fragmentable_len;
-    IPV4_CACHE_INIT(rp);
 
 remove_tracker:
     /* Remove the frag tracker. */
     SCMutexLock(&dc->frag_table_lock);
-    HashListTableRemove(dc->frag_table, tracker, sizeof(tracker));
+    HashListTableRemove(dc->frag_table, tracker, sizeof(*tracker));
     SCMutexUnlock(&dc->frag_table_lock);
     DefragTrackerReset(tracker);
     SCMutexLock(&dc->tracker_pool_lock);
@@ -698,12 +700,11 @@ Defrag6Reassemble(ThreadVars *tv, DefragContext *dc, DefragTracker *tracker,
     rp->ip6h->s_ip6_plen = htons(fragmentable_len);
     rp->ip6h->s_ip6_nxt = next_hdr;
     rp->pktlen = ip_hdr_offset + sizeof(IPV6Hdr) + fragmentable_len;
-    IPV6_CACHE_INIT(rp);
 
 remove_tracker:
     /* Remove the frag tracker. */
     SCMutexLock(&dc->frag_table_lock);
-    HashListTableRemove(dc->frag_table, tracker, sizeof(tracker));
+    HashListTableRemove(dc->frag_table, tracker, sizeof(*tracker));
     SCMutexUnlock(&dc->frag_table_lock);
     DefragTrackerReset(tracker);
     SCMutexLock(&dc->tracker_pool_lock);
@@ -1239,7 +1240,6 @@ BuildTestPacket(uint16_t id, uint16_t off, int mf, const char content,
     p->ip4h->ip_csum = IPV4CalculateChecksum((uint16_t *)p->pkt, hlen);
 
     /* Self test. */
-    IPV4_CACHE_INIT(p);
     if (IPV4_GET_VER(p) != 4)
         goto error;
     if (IPV4_GET_HLEN(p) != hlen)
@@ -1306,7 +1306,6 @@ IPV6BuildTestPacket(uint32_t id, uint16_t off, int mf, const char content,
     SET_IPV6_DST_ADDR(p, &p->dst);
 
     /* Self test. */
-    IPV6_CACHE_INIT(p);
     if (IPV6_GET_VER(p) != 6)
         goto error;
     if (IPV6_GET_NH(p) != 44)
