@@ -136,6 +136,8 @@ static int DetectPktvarSetup (DetectEngineCtx *de_ctx, Signature *s, char *rawst
 
     if (varcontent[0] == '\"' && varcontent[strlen(varcontent)-1] == '\"') {
         str = SCStrdup(varcontent+1);
+        if (str == NULL)
+            goto error;
         str[strlen(varcontent)-2] = '\0';
         dubbed = 1;
     }
