@@ -742,6 +742,9 @@ enum {
     DETECT_URICONTENT,
     DETECT_PCRE,
     DETECT_PCRE_HTTPBODY,
+    DETECT_PCRE_HTTPCOOKIE,
+    DETECT_PCRE_HTTPHEADER,
+    DETECT_PCRE_HTTPMETHOD,
     DETECT_ACK,
     DETECT_SEQ,
     DETECT_DEPTH,
@@ -801,6 +804,8 @@ enum {
     DETECT_AL_HTTP_CLIENT_BODY,
     DETECT_AL_HTTP_HEADER,
     DETECT_AL_HTTP_URI,
+    DETECT_AL_SSH_PROTOVERSION,
+    DETECT_AL_SSH_SOFTWAREVERSION,
 
     DETECT_DCE_IFACE,
     DETECT_DCE_OPNUM,
