@@ -1575,6 +1575,8 @@ static int FlowTest03 (void) {
     FlowBucket fb;
     struct timeval ts;
 
+    FlowQueueInit(&flow_spare_q);
+
     memset(&ssn, 0, sizeof(TcpSession));
     memset(&f, 0, sizeof(Flow));
     memset(&ts, 0, sizeof(ts));
@@ -1594,11 +1596,14 @@ static int FlowTest03 (void) {
     if (FlowTestPrune(&f, &ts) != 1) {
         SCSpinDestroy(&fb.s);
         FLOW_DESTROY(&f);
+        FlowQueueDestroy(&flow_spare_q);
         return 0;
     }
 
     SCSpinDestroy(&fb.s);
-    //FLOW_DESTROY(&f);
+    FLOW_DESTROY(&f);
+
+    FlowQueueDestroy(&flow_spare_q);
     return 1;
 }
 
@@ -1619,6 +1624,8 @@ static int FlowTest04 (void) {
     TcpStream client;
     uint8_t payload[3] = {0x41, 0x41, 0x41};
 
+    FlowQueueInit(&flow_spare_q);
+
     memset(&ssn, 0, sizeof(TcpSession));
     memset(&f, 0, sizeof(Flow));
     memset(&fb, 0, sizeof(FlowBucket));
@@ -1646,10 +1653,12 @@ static int FlowTest04 (void) {
     if (FlowTestPrune(&f, &ts) != 1) {
         SCSpinDestroy(&fb.s);
         FLOW_DESTROY(&f);
+        FlowQueueDestroy(&flow_spare_q);
         return 0;
     }
     SCSpinDestroy(&fb.s);
-    //FLOW_DESTROY(&f);
+    FLOW_DESTROY(&f);
+    FlowQueueDestroy(&flow_spare_q);
     return 1;
 
 }
@@ -1668,6 +1677,8 @@ static int FlowTest05 (void) {
     FlowBucket fb;
     struct timeval ts;
 
+    FlowQueueInit(&flow_spare_q);
+
     memset(&ssn, 0, sizeof(TcpSession));
     memset(&f, 0, sizeof(Flow));
     memset(&ts, 0, sizeof(ts));
@@ -1687,11 +1698,13 @@ static int FlowTest05 (void) {
     if (FlowTestPrune(&f, &ts) != 1) {
         SCSpinDestroy(&fb.s);
         FLOW_DESTROY(&f);
+        FlowQueueDestroy(&flow_spare_q);
         return 0;
     }
 
     SCSpinDestroy(&fb.s);
-    //FLOW_DESTROY(&f);
+    FLOW_DESTROY(&f);
+    FlowQueueDestroy(&flow_spare_q);
     return 1;
 }
 
@@ -1712,6 +1725,8 @@ static int FlowTest06 (void) {
     TcpStream client;
     uint8_t payload[3] = {0x41, 0x41, 0x41};
 
+    FlowQueueInit(&flow_spare_q);
+
     memset(&ssn, 0, sizeof(TcpSession));
     memset(&f, 0, sizeof(Flow));
     memset(&fb, 0, sizeof(FlowBucket));
@@ -1740,11 +1755,13 @@ static int FlowTest06 (void) {
     if (FlowTestPrune(&f, &ts) != 1) {
         SCSpinDestroy(&fb.s);
         FLOW_DESTROY(&f);
+        FlowQueueDestroy(&flow_spare_q);
         return 0;
     }
 
     SCSpinDestroy(&fb.s);
-    //FLOW_DESTROY(&f);
+    FLOW_DESTROY(&f);
+    FlowQueueDestroy(&flow_spare_q);
     return 1;
 
 }
