@@ -298,6 +298,7 @@ static void SetBpfString(int optind, char *argv[]) {
             exit(EXIT_FAILURE);
         }
     }
+    SCFree(bpf_filter);
 }
 
 void usage(const char *progname)
@@ -1036,6 +1037,11 @@ int main(int argc, char **argv)
     FlowInitConfig(FLOW_VERBOSE);
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
+    if (de_ctx == NULL) {
+        SCLogError(SC_ERR_INITIALIZATION, "initializing detection engine "
+            "context failed.");
+        exit(EXIT_FAILURE);
+    }
 
     SCClassConfLoadClassficationConfigFile(de_ctx);
 
