@@ -486,15 +486,15 @@ int SCLogPrintFGFilters()
  */
 int SCLogMatchFDFilter(const char *function)
 {
+#ifndef DEBUG
+    return 1;
+#else
+
     SCLogFDFilterThreadList *thread_list = NULL;
 
 //    pid_t self = syscall(SYS_gettid);
     pthread_t self = pthread_self();
 
-#ifndef DEBUG
-    return 1;
-#endif
-
     if (sc_log_module_initialized != 1) {
         printf("Logging module not initialized.  Call SCLogInitLogModule() "
                "first before using the debug API\n");
@@ -527,6 +527,8 @@ int SCLogMatchFDFilter(const char *function)
     SCMutexUnlock(&sc_log_fd_filters_tl_m);
 
     return 0;
+
+#endif /* #else - #ifndef DEBUG */
 }
 
 /**
@@ -575,9 +577,7 @@ int SCLogCheckFDFilterEntry(const char *function)
     SCMutexLock(&sc_log_fd_filters_tl_m);
 
     thread_list = sc_log_fd_filters_tl;
-    thread_list_temp = thread_list;
     while (thread_list != NULL) {
-        thread_list_temp = thread_list;
 
         if (pthread_equal(self, thread_list->t))
             break;
@@ -591,8 +591,10 @@ int SCLogCheckFDFilterEntry(const char *function)
         return 1;
     }
 
-    if ( (thread_list_temp = SCMalloc(sizeof(SCLogFDFilterThreadList))) == NULL)
+    if ( (thread_list_temp = SCMalloc(sizeof(SCLogFDFilterThreadList))) == NULL) {
+        SCMutexUnlock(&sc_log_fd_filters_tl_m);
         return 0;
+    }
     memset(thread_list_temp, 0, sizeof(SCLogFDFilterThreadList));
 
     thread_list_temp->t = self;
@@ -705,8 +707,10 @@ int SCLogAddFDFilter(const char *function)
         curr = curr->next;
     }
 
-    if ( (temp = SCMalloc(sizeof(SCLogFDFilter))) == NULL)
+    if ( (temp = SCMalloc(sizeof(SCLogFDFilter))) == NULL) {
+        SCMutexUnlock(&sc_log_fd_filters_m);
         return -1;
+    }
     memset(temp, 0, sizeof(SCLogFDFilter));
 
     if ( (temp->func = SCStrdup(function)) == NULL) {
@@ -716,7 +720,10 @@ int SCLogAddFDFilter(const char *function)
 
     if (sc_log_fd_filters == NULL)
         sc_log_fd_filters = temp;
-    else
+    /* clang thinks prev can be NULL, but it can't be unless
+     * sc_log_fd_filters is also NULL which is handled here.
+     * Doing this "fix" to shut clang up. */
+    else if (prev != NULL)
         prev->next = temp;
 
     SCMutexUnlock(&sc_log_fd_filters_m);
@@ -821,7 +828,6 @@ int SCLogPrintFDFilters(void)
 {
     SCLogFDFilter *fdf = NULL;
     int count = 0;
-    int r = 0;
 
     if (sc_log_module_initialized != 1) {
         printf("Logging module not initialized.  Call SCLogInitLogModule() "
@@ -833,7 +839,7 @@ int SCLogPrintFDFilters(void)
     printf("FD filters:\n");
 #endif
 
-    r = SCMutexLock(&sc_log_fd_filters_m);
+    SCMutexLock(&sc_log_fd_filters_m);
 
     fdf = sc_log_fd_filters;
     while (fdf != NULL) {
@@ -844,7 +850,7 @@ int SCLogPrintFDFilters(void)
         count++;
     }
 
-    r = SCMutexUnlock(&sc_log_fd_filters_m);
+    SCMutexUnlock(&sc_log_fd_filters_m);
 
     return count;
 }
